@@ -36,12 +36,21 @@ DIAG_OVER_MAX_ARGS      =
 'Esta función espera un máximo de {:d} argumento(s), pero está recibiendo {:d}.'
 DIAG_MISS_ARGS          =
 'Esta función requiere {:d} argumento(s), pero está recibiendo {:d}.'
+DIAG_UNNECESSARY_ASSERT =
+'Aserción innecesaria: esta expresión siempre es verdadera.'
 DIAG_OVER_MAX_VALUES    =
 'Solo tiene {} variables, pero se están asignando {} valores.'
 DIAG_AMBIGUITY_1        =
 'Se calcula `{}` primero. Agregar corchetes podría ser necesario.'
 DIAG_LOWERCASE_GLOBAL   =
 'Variable global con inicial minúscula, ¿olvidó agregar `local` o está mal escrita?'
+
+ASSIGN_CONST_GLOBAL     =
+'No se puede asignar a la variable global <const> `{}`.'
+
+VARIABLE_NOT_DECLARED =
+'Variable `{}` no declarada (declaraciones globales activas).'
+
 DIAG_EMPTY_BLOCK        =
 'Bloque vacío.'
 DIAG_DIAGNOSTICS        =
@@ -375,6 +384,8 @@ HOVER_DOCUMENT_LUA53   =
 'http://www.lua.org/manual/5.3/manual.html#{}'
 HOVER_DOCUMENT_LUA54   =
 'http://www.lua.org/manual/5.4/manual.html#{}'
+HOVER_DOCUMENT_LUA55    =
+'https://www.lua.org/manual/5.5/manual.html#{}'
 HOVER_DOCUMENT_LUAJIT  =
 'http://www.lua.org/manual/5.1/manual.html#{}'
 HOVER_NATIVE_DOCUMENT_LUA51    =
@@ -385,6 +396,8 @@ HOVER_NATIVE_DOCUMENT_LUA53    =
 'command:extension.lua.doc?["en-us/53/manual.html/{}"]'
 HOVER_NATIVE_DOCUMENT_LUA54    =
 'command:extension.lua.doc?["en-us/54/manual.html/{}"]'
+HOVER_NATIVE_DOCUMENT_LUA55     =
+'command:extension.lua.doc?["en-us/55/manual.html/{}"]'
 HOVER_NATIVE_DOCUMENT_LUAJIT   =
 'command:extension.lua.doc?["en-us/51/manual.html/{}"]'
 HOVER_MULTI_PROTOTYPE     =
@@ -662,6 +675,10 @@ CLI_CHECK_PROGRESS=
 'Se encontraron {} problema(s) en {} archivo(s)'
 CLI_CHECK_RESULTS=
 'Se completó el diagnóstico, se encontraron {} problema(s), vea {}'
+CLI_CHECK_RESULTS_OUTPATH =
+'Diagnóstico completado, se encontraron {} problema(s), vea {}'
+CLI_CHECK_RESULTS_PRETTY =
+'Diagnóstico completado, se encontraron {} problema(s)'
 CLI_CHECK_MULTIPLE_WORKERS=
 'Iniciando {} tarea(s) de trabajo, se ha deshabitado la salida de progreso. Esto podría tomar unos minutos.'
 CLI_DOC_INITING  =
