@@ -6,82 +6,129 @@ config.addonManager.repositoryBranch =
 "アドオンマネージャーが使用するgitブランチを指定します。"
 config.addonManager.repositoryPath =
 "アドオンマネージャーが使用するgitパスを指定します。"
-config.develop.enable                    =
-'開発者モード。パフォーマンスに影響するため有効にしないでください。'
-config.develop.debuggerPort              =
-'デバッガーの待ち受けポート。'
-config.develop.debuggerWait              =
-'デバッガー接続前に停止します。'
-config.intelliSense.searchDepth          =
-'IntelliSenseの検索深度を設定します。この値を上げると精度が上がりますが、パフォーマンスが低下します。ワークスペースごとに適切な値を調整してください。'
-config.intelliSense.fastGlobal           =
-'グローバル変数補完および `_G` ホバー表示を高速化します。型推論の精度がわずかに低下しますが、多数のグローバルを使うプロジェクトでは大きく改善します。'
-config.window.statusBar                  =
-'ステータスバーに拡張機能のステータスを表示します。'
-config.window.progressBar                =
-'ステータスバーに進行状況バーを表示します。'
-config.hint.enable                       =
-'インレイヒントを有効にします。'
-config.hint.paramType                    =
-'関数のパラメータに型ヒントを表示します。'
-config.hint.setType                      =
-'代入操作で型ヒントを表示します。'
-config.hint.paramName                    =
-'関数呼び出し時にパラメータ名のヒントを表示します。'
-config.hint.paramName.All                =
-'すべての型のパラメータを表示します。'
-config.hint.paramName.Literal            =
-'リテラル型のパラメータのみを表示します。'
-config.hint.paramName.Disable            =
-'パラメータヒントを無効にします。'
-config.hint.arrayIndex                   =
-'テーブル構築時に配列インデックスのヒントを表示します。'
-config.hint.arrayIndex.Enable            =
-'すべてのテーブルでヒントを表示します。'
-config.hint.arrayIndex.Auto              =
-'テーブルが3要素を超える、または混在テーブルの場合のみヒントを表示します。'
-config.hint.arrayIndex.Disable           =
-'配列インデックスのヒントを無効にします。'
-config.hint.await                        =
-'呼び出す関数に `---@async` が付いている場合、呼び出し箇所で `await` を提案します。'
-config.hint.awaitPropagate               =
-'`await` の伝播を有効にします。`---@async` が付いた関数を呼び出す関数は、自動的に `---@async` とマークされます。'
-config.hint.semicolon                    =
-'文末にセミコロンがない場合に仮想セミコロンを表示します。'
-config.hint.semicolon.All                =
-'すべての文で仮想セミコロンを表示します。'
-config.hint.semicolon.SameLine           =
-'同じ行に2つの文がある場合、その間にセミコロンを表示します。'
-config.hint.semicolon.Disable            =
-'仮想セミコロンを無効にします。'
-config.codeLens.enable                   =
-'コードレンズを有効にします。'
-config.format.enable                     =
-'コードフォーマッタを有効にします。'
-config.format.defaultConfig              =
+config.addonRepositoryPath        =
+"アドオンのリポジトリパスを指定します（アドオンマネージャーとは無関係です）。"
+config.runtime.version            =
+"Lua のランタイムバージョン。"
+config.runtime.path               =
 [[
-デフォルトのフォーマット設定。ワークスペース内の`.editorconfig`ファイルより優先度が低くなります。
-[formatter docs](https://github.com/CppCXY/EmmyLuaCodeStyle/tree/master/docs) を参照してください。
+`require` を使用する際、入力名に基づいてファイルを探す方法。
+この設定を `?/init.lua` にすると、`require 'myfile'` と入力したとき、読み込まれたファイルから `${workspace}/myfile/init.lua` が検索されます。
+`runtime.pathStrict` が `false` の場合、`${workspace}/**/myfile/init.lua` も検索対象になります。
+ワークスペース外のファイルを読み込みたい場合は、先に `Lua.workspace.library` を設定する必要があります。
 ]]
-config.spell.dict                        =
-'スペルチェック用のカスタム単語。'
-config.nameStyle.config                  =
+config.runtime.pathStrict         =
+'有効にすると、`runtime.path` は最上位のディレクトリ階層のみを検索します。詳細は `runtime.path` の説明を参照してください。'
+config.runtime.special            =
+[[カスタムのグローバル変数を一部の特別な組み込み変数として扱い、言語サーバーが特別なサポートを提供します。
+以下の例では、`include` を `require` として扱います。
+```json
+"Lua.runtime.special" : {
+    "include" : "require"
+}
+```
+]]
+config.runtime.unicodeName        =
+"名前に Unicode 文字を使用できるようにします。"
+config.runtime.nonstandardSymbol  =
+"非標準の記号をサポートします。ランタイム環境がこれらの記号をサポートしていることを確認してください。"
+config.runtime.plugin             =
+"プラグインのパス。詳細は [wiki](https://luals.github.io/wiki/plugins) を参照してください。"
+config.runtime.pluginArgs         =
+"プラグインに渡す追加引数。"
+config.runtime.fileEncoding       =
+"ファイルのエンコーディング。`ansi` オプションは `Windows` プラットフォームでのみ利用可能です。"
+config.runtime.builtin            =
 [[
-命名スタイル設定。
-[formatter docs](https://github.com/CppCXY/EmmyLuaCodeStyle/tree/master/docs) を参照してください。
+組み込みライブラリの有効状態を調整します。実際のランタイム環境に応じて、存在しないライブラリを無効化（または再定義）できます。
+
+* `default`: ランタイムバージョンに応じてライブラリを有効／無効にします
+* `enable`: 常に有効
+* `disable`: 常に無効
 ]]
-config.telemetry.enable                  =
+config.runtime.meta               =
+'メタファイルのディレクトリ名の形式。'
+config.diagnostics.enable         =
+"診断を有効にします。"
+config.diagnostics.disable        =
+"無効化する診断（ホバーの括弧内に表示されるコードを使用）。"
+config.diagnostics.globals        =
+"定義済みのグローバル変数。"
+config.diagnostics.globalsRegex   =
+"正規表現で定義済みのグローバル変数を検索します。"
+config.diagnostics.severity       =
 [[
-テレメトリを有効にし、エディタ情報とエラーログをネットワーク経由で送信します。プライバシーポリシーは[こちら](https://luals.github.io/privacy/#language-server)。
+診断の重大度を変更します。
+
+末尾に `!` を付けると、グループ設定 `diagnostics.groupSeverity` を上書きします。
 ]]
-config.misc.parameters                   =
-'VSCode で言語サーバーを起動するときの[コマンドライン引数](https://github.com/LuaLS/lua-telemetry-server/tree/master/method)。'
-config.misc.executablePath               =
-'VSCodeでの実行可能ファイルのパスを指定します。'
-config.language.fixIndent                =
-'(VSCodeのみ) 誤った自動インデントを修正します。例えば、"function" を含む文字列内で改行したときの不正なインデントなど。'
-config.language.completeAnnotation       =
-'(VSCodeのみ) 注釈行の改行後に自動で "---@ " を挿入します。'
+config.diagnostics.neededFileStatus =
+[[
+* Opened: 開いているファイルのみを診断
+* Any:    すべてのファイルを診断
+* None:   この診断を無効化
+
+末尾に `!` を付けると、グループ設定 `diagnostics.groupFileStatus` を上書きします。
+]]
+config.diagnostics.groupSeverity  =
+[[
+グループ内の診断の重大度を変更します。
+`Fallback` は、このグループ内の診断が個別に `diagnostics.severity` によって制御されることを意味します。
+その他の設定は、末尾に `!` が付いていない個別の設定を上書きします。
+]]
+config.diagnostics.groupFileStatus =
+[[
+グループ内の診断対象ファイル状態を変更します。
+
+* Opened: 開いているファイルのみを診断
+* Any:    すべてのファイルを診断
+* None:   この診断を無効化
+
+`Fallback` は、このグループ内の診断が個別に `diagnostics.neededFileStatus` によって制御されることを意味します。
+その他の設定は、末尾に `!` が付いていない個別の設定を上書きします。
+]]
+config.diagnostics.workspaceEvent =
+"ワークスペース診断をトリガーするタイミングを設定します。"
+config.diagnostics.workspaceEvent.OnChange =
+"ファイルが変更されたときにワークスペース診断をトリガーします。"
+config.diagnostics.workspaceEvent.OnSave =
+"ファイルが保存されたときにワークスペース診断をトリガーします。"
+config.diagnostics.workspaceEvent.None =
+"ワークスペース診断を無効にします。"
+config.diagnostics.workspaceDelay =
+"ワークスペース診断の待ち時間（ミリ秒）。"
+config.diagnostics.workspaceRate  =
+"ワークスペース診断の実行レート（％）。この値を下げると CPU 使用率は低下しますが、ワークスペース診断の速度も低下します。現在編集中のファイルの診断は常に全速で行われ、この設定の影響を受けません。"
+config.diagnostics.libraryFiles   =
+"`Lua.workspace.library` 経由で読み込まれたファイルをどのように診断するか。"
+config.diagnostics.libraryFiles.Enable   =
+"常にこれらのファイルを診断します。"
+config.diagnostics.libraryFiles.Opened   =
+"これらのファイルが開かれているときのみ診断します。"
+config.diagnostics.libraryFiles.Disable  =
+"これらのファイルは診断しません。"
+config.diagnostics.ignoredFiles   =
+"無視されているファイルをどのように診断するか。"
+config.diagnostics.ignoredFiles.Enable   =
+"常にこれらのファイルを診断します。"
+config.diagnostics.ignoredFiles.Opened   =
+"これらのファイルが開かれているときのみ診断します。"
+config.diagnostics.ignoredFiles.Disable  =
+"これらのファイルは診断しません。"
+config.diagnostics.disableScheme  =
+'次のスキームを使用する Lua ファイルは診断しません。'
+config.diagnostics.validScheme  =
+'次のスキームを使用する Lua ファイルの診断を有効にします。'
+config.diagnostics.unusedLocalExclude =
+'変数名が次のパターンに一致する場合、`unused-local` を診断しません。'
+config.workspace.ignoreDir        =
+"無視するファイルとディレクトリ（`.gitignore` の構文を使用）。"-- .. example.ignoreDir,
+config.workspace.ignoreSubmodules =
+"サブモジュールを無視します。"
+config.workspace.useGitIgnore     =
+"`.gitignore` に記載されたファイルを無視します。"
+config.workspace.maxPreload       =
+"プリロードする最大ファイル数。"
 config.workspace.preloadFileSize  =
 "プリロード時にこの値（KB）より大きいファイルをスキップします。"
 config.workspace.library          =
@@ -177,6 +224,82 @@ config.hover.expandAlias                 =
 [[
 エイリアスを展開するかどうか。たとえば、`---@alias myType boolean|number`を展開すると`boolean|number`として表示され、そうでない場合は`myType`として表示されます。
 ]]
+config.develop.enable                    =
+'開発者モード。パフォーマンスに影響するため有効にしないでください。'
+config.develop.debuggerPort              =
+'デバッガーの待ち受けポート。'
+config.develop.debuggerWait              =
+'デバッガー接続前に停止します。'
+config.intelliSense.searchDepth          =
+'IntelliSenseの検索深度を設定します。この値を上げると精度が上がりますが、パフォーマンスが低下します。ワークスペースごとに適切な値を調整してください。'
+config.intelliSense.fastGlobal           =
+'グローバル変数補完および `_G` ホバー表示を高速化します。型推論の精度がわずかに低下しますが、多数のグローバルを使うプロジェクトでは大きく改善します。'
+config.window.statusBar                  =
+'ステータスバーに拡張機能のステータスを表示します。'
+config.window.progressBar                =
+'ステータスバーに進行状況バーを表示します。'
+config.hint.enable                       =
+'インレイヒントを有効にします。'
+config.hint.paramType                    =
+'関数のパラメータに型ヒントを表示します。'
+config.hint.setType                      =
+'代入操作で型ヒントを表示します。'
+config.hint.paramName                    =
+'関数呼び出し時にパラメータ名のヒントを表示します。'
+config.hint.paramName.All                =
+'すべての型のパラメータを表示します。'
+config.hint.paramName.Literal            =
+'リテラル型のパラメータのみを表示します。'
+config.hint.paramName.Disable            =
+'パラメータヒントを無効にします。'
+config.hint.arrayIndex                   =
+'テーブル構築時に配列インデックスのヒントを表示します。'
+config.hint.arrayIndex.Enable            =
+'すべてのテーブルでヒントを表示します。'
+config.hint.arrayIndex.Auto              =
+'テーブルが3要素を超える、または混在テーブルの場合のみヒントを表示します。'
+config.hint.arrayIndex.Disable           =
+'配列インデックスのヒントを無効にします。'
+config.hint.await                        =
+'呼び出す関数に `---@async` が付いている場合、呼び出し箇所で `await` を提案します。'
+config.hint.awaitPropagate               =
+'`await` の伝播を有効にします。`---@async` が付いた関数を呼び出す関数は、自動的に `---@async` とマークされます。'
+config.hint.semicolon                    =
+'文末にセミコロンがない場合に仮想セミコロンを表示します。'
+config.hint.semicolon.All                =
+'すべての文で仮想セミコロンを表示します。'
+config.hint.semicolon.SameLine           =
+'同じ行に2つの文がある場合、その間にセミコロンを表示します。'
+config.hint.semicolon.Disable            =
+'仮想セミコロンを無効にします。'
+config.codeLens.enable                   =
+'コードレンズを有効にします。'
+config.format.enable                     =
+'コードフォーマッタを有効にします。'
+config.format.defaultConfig              =
+[[
+デフォルトのフォーマット設定。ワークスペース内の`.editorconfig`ファイルより優先度が低くなります。
+[formatter docs](https://github.com/CppCXY/EmmyLuaCodeStyle/tree/master/docs) を参照してください。
+]]
+config.spell.dict                        =
+'スペルチェック用のカスタム単語。'
+config.nameStyle.config                  =
+[[
+命名スタイル設定。
+[formatter docs](https://github.com/CppCXY/EmmyLuaCodeStyle/tree/master/docs) を参照してください。
+]]
+config.telemetry.enable                  =
+[[
+テレメトリを有効にし、エディタ情報とエラーログをネットワーク経由で送信します。プライバシーポリシーは[こちら](https://luals.github.io/privacy/#language-server)。
+]]
+config.misc.parameters                   =
+'VSCode で言語サーバーを起動するときの[コマンドライン引数](https://github.com/LuaLS/lua-telemetry-server/tree/master/method)。'
+config.misc.executablePath               =
+'VSCodeでの実行可能ファイルのパスを指定します。'
+config.language.fixIndent                =
+'(VSCodeのみ) 誤った自動インデントを修正します。例えば、"function" を含む文字列内で改行したときの不正なインデントなど。'
+config.language.completeAnnotation       =
+'(VSCodeのみ) 注釈行の改行後に自動で "---@ " を挿入します。'
 config.type.castNumberToInteger          =
 '`number` 型を `integer` 型に代入することを許可します。'
 config.type.weakUnionCheck               =
