@@ -22,34 +22,36 @@ arg = {}
 function assert(v, message, ...) end
 
 
----@alias gcoptions
----|>"collect"      # 做一次完整的垃圾收集循环。
----| "stop"         # 停止垃圾收集器的运行。
----| "restart"      # 重启垃圾收集器的自动运行。
----| "count"        # 以 K 字节数为单位返回 Lua 使用的总内存数。
----| "step"         # 执行一次垃圾收集的“步骤”。此选项后可以带一个额外参数 `size`（整数）。...如果 `size` 为正的 n，收集器的行为就像新分配了 n 个字节；如果为 0，则执行一个“基本步骤”。...在增量模式下，基本步骤对应当前的步进大小；在分代模式下，基本步骤会执行一次完整的次要收集，...或在收集器已安排增量步骤时执行该增量步骤。...在增量模式下，如果该步骤完成了一个收集周期，函数返回 `true`；在分代模式下，如果该步骤完成了一个主要收集，返回 `true`。...
----| "isrunning"    # 返回表示收集器是否在工作的布尔值。
----| "incremental"  # 将收集器模式改为“增量模式”，并返回之前的模式（可能是 `"generational"` 或 `"incremental"`）。
----| "generational" # 将收集器模式改为“分代模式”，并返回之前的模式（可能是 `"generational"` 或 `"incremental"`）。
+
 
 ---
----该函数是垃圾收集器的通用接口，根据第一个参数 `opt` 执行不同的功能：
----• `"collect"`：执行一次完整的垃圾收集循环（默认选项）。
----• `"stop"`：停止垃圾收集器的自动执行；之后仅在显式调用时运行，直到 `"restart"`。
----• `"restart"`：重启垃圾收集器的自动执行。
----• `"count"`：返回 Lua 当前使用的总内存（单位为 K字节，含小数；乘以 1024 得到字节数）。
----• `"step"`：执行一次垃圾收集步骤，可选参数 `size` 控制步长；行为与返回值见 `cgopt.step` 的说明。
----• `"isrunning"`：返回一个布尔值，指示收集器是否正在运行（即未被停止）。
----• `"incremental"`：将模式改为增量模式，并返回之前的模式。
----• `"generational"`：将模式改为分代模式，并返回之前的模式。
----• `"param"`：更改/检索收集器参数（见各 `gcparam.*` 项），总是返回该参数的先前值。
+---此函数是垃圾收集器的通用接口。根据其第一个参数 opt 执行不同的功能：
+---
+---* `"collect"`：执行一个完整的垃圾收集周期。这是默认选项。
+---* `"stop"`：停止垃圾收集器的自动执行。收集器将仅在显式调用时运行，直到调用重启它。
+---* `"restart"`：重启垃圾收集器的自动执行。
+---* `"count"`：返回 Lua 使用的总内存数（以 K 字节为单位）。该值有小数部分，因此乘以 1024 即可得到 Lua 使用的精确字节数。
+---* `"step"`：执行一次垃圾收集步骤。步骤的"大小"由 arg 控制。值为零时，收集器将执行一个基本（不可分割的）步骤。对于非零值，收集器的行为就像 Lua 分配了相应数量的内存（以 K 字节为单位）。如果步骤完成了一个收集周期则返回 true。
+---* `"isrunning"`：返回一个布尔值，指示收集器是否正在运行（即未停止）。
+---* `"incremental"`：将收集器模式更改为增量模式。此选项后可以跟三个数字：垃圾收集器间歇率、步进倍率和步进大小（参见 [§2.5.1](command:extension.lua.doc?["en-us/54/manual.html/2.5.1"])）。零表示不更改该值。
+---* `"generational"`：将收集器模式更改为分代模式。此选项后可以跟两个数字：垃圾收集器次要乘数和主要乘数（参见 [§2.5.2](command:extension.lua.doc?["en-us/54/manual.html/2.5.2"])）。零表示不更改该值。
+---有关垃圾收集和其中一些选项的更多详细信息，请参见 [§2.5](command:extension.lua.doc?["en-us/54/manual.html/2.5"])。
+---
+---终结器不应调用此函数。
 ---
 ---
----[查看文档](command:extension.lua.doc?["en-us/54/manual.html/pdf-collectgarbage"])
+---[查看文档](command:extension.lua.doc?["en-us/54/manual.html/pdf-collectgarbage54"])
 ---
----@param opt? gcoptions
----@return any
-function collectgarbage(opt, ...) end
+---@overload fun(opt?: "collect")
+---@overload fun(opt: "stop")
+---@overload fun(opt: "restart")
+---@overload fun(opt: "count"): number
+---@overload fun(opt: "step", arg: integer): true
+---@overload fun(opt: "isrunning"): boolean
+---@overload fun(opt: "incremental", pause?: integer, multiplier?: integer, stepsize?: integer)
+---@overload fun(opt: "generational", minor?: integer, major?: integer)
+function collectgarbage(...) end
+
 
 ---
 ---打开该名字的文件，并执行文件中的 Lua 代码块。 不带参数调用时， `dofile` 执行标准输入的内容（`stdin`）。 返回该代码块的所有返回值。 对于有错误的情况，`dofile` 将错误反馈给调用者 （即，`dofile` 没有运行在保护模式下）。
