@@ -480,12 +480,12 @@ local function tryModifyClientGlobal(finalChanges)
     end
     log.info('tryModifyClientGlobal', inspect(finalChanges))
     if not m.getOption 'changeConfiguration' then
-        log.info('Client dose not support modifying config')
+        log.info('Client does not support modifying config')
         return
     end
     local changes = {}
     for _, change in ipairs(finalChanges) do
-        if change.global then
+        if change['global'] then
             changes[#changes+1] = change
         end
     end
