@@ -6,8 +6,9 @@ local util      = require 'utility'
 local lang      = require 'language'
 
 ---@class vm.ANY
----@diagnostic disable-next-line: assign-type-mismatch
-vm.ANY = debug.upvalueid(require, 1)
+vm.ANY = {'<VM.ANY>'}
+---@class vm.ANYDOC
+vm.ANYDOC = {'<VM.ANYDOC>'}
 
 ---@alias typecheck.err vm.node.object|string|vm.node
 
@@ -276,11 +277,11 @@ end
 ---@param suri uri
 ---@return boolean
 local function isAlias(name, suri)
-    local global = vm.getGlobal('type', name)
-    if not global then
+    local globalVar = vm.getGlobal('type', name)
+    if not globalVar then
         return false
     end
-    for _, set in ipairs(global:getSets(suri)) do
+    for _, set in ipairs(globalVar:getSets(suri)) do
         if set.type == 'doc.alias' then
             return true
         end
@@ -365,15 +366,21 @@ function vm.isSubType(uri, child, parent, mark, errs)
     mark = mark or {}
 
     if type(child) == 'string' then
-        local global = vm.getGlobal('type', child)
-        if not global then
+        local globalVar = vm.getGlobal('type', child)
+        if not globalVar then
             return nil
         end
-        child = global
+        child = globalVar
     elseif child.type == 'vm.node' then
         if config.get(uri, 'Lua.type.weakUnionCheck') then
             local hasKnownType = 0
+            local maxUnionVariants = config.get(uri, 'Lua.type.maxUnionVariants') or 0
+            local i = 0
             for n in child:eachObject() do
+                i = i + 1
+                if maxUnionVariants > 0 and i > maxUnionVariants then
+                    break
+                end
                 if vm.getNodeName(n) then
                     local res = vm.isSubType(uri, n, parent, mark, errs)
                     if res == true then
@@ -397,7 +404,13 @@ function vm.isSubType(uri, child, parent, mark, errs)
         else
             local weakNil = config.get(uri, 'Lua.type.weakNilCheck')
             local skipTable
+            local maxUnionVariants = config.get(uri, 'Lua.type.maxUnionVariants') or 0
+            local i = 0
             for n in child:eachObject() do
+                i = i + 1
+                if maxUnionVariants > 0 and i > maxUnionVariants then
+                    break
+                end
                 if skipTable == nil and n.type == "table" and parent.type == "vm.node" then -- skip table type check if child has class
                     ---@cast parent vm.node
                     for _, c in ipairs(child) do
@@ -455,14 +468,20 @@ function vm.isSubType(uri, child, parent, mark, errs)
     end
 
     if type(parent) == 'string' then
-        local global = vm.getGlobal('type', parent)
-        if not global then
+        local globalVar = vm.getGlobal('type', parent)
+        if not globalVar then
             return false
         end
-        parent = global
+        parent = globalVar
     elseif parent.type == 'vm.node' then
         local hasKnownType = 0
+        local maxUnionVariants = config.get(uri, 'Lua.type.maxUnionVariants') or 0
+        local i = 0
         for n in parent:eachObject() do
+            i = i + 1
+            if maxUnionVariants > 0 and i > maxUnionVariants then
+                break
+            end
             if vm.getNodeName(n) then
                 local res = vm.isSubType(uri, child, n, mark, errs)
                 if res == true then
@@ -880,12 +899,12 @@ end
 ---@param uri uri
 ---@return parser.object[]?
 function vm.getOverloadsByTypeName(name, uri)
-    local global = vm.getGlobal('type', name)
-    if not global then
+    local globalVar = vm.getGlobal('type', name)
+    if not globalVar then
         return nil
     end
     local results
-    for _, set in ipairs(global:getSets(uri)) do
+    for _, set in ipairs(globalVar:getSets(uri)) do
         for _, doc in ipairs(set.bindGroup) do
             if doc.type == 'doc.overload' then
                 if not results then
